@@ -1,4 +1,4 @@
-dominate.greedy <- function(g,weight=NULL)
+dominate.greedy <- function(g,weight=NULL,proportion=1.0)
 {
    od <- degree(g,mode="out")+1
    S <- NULL
@@ -6,7 +6,7 @@ dominate.greedy <- function(g,weight=NULL)
    diag(A) <- 0
    n <- nrow(A)
    covered <- rep(0,n)
-   while(sum(covered)<n){
+   while(sum(covered)<n*proportion){
       i <- which.max(od)
 		if(!is.null(weight)){
 		   qq <- weight
@@ -23,18 +23,18 @@ dominate.greedy <- function(g,weight=NULL)
    S
 }
 
-dominate.byR <- function(g)
+dominate.byR <- function(g,proportion=1.0)
 {
-   dominate.greedy(g,weight=g$R)
+   dominate.greedy(g,weight=g$R,proportion=proportion)
 }
 
-dominate.random.sample <- function(g)
+dominate.random.sample <- function(g,proportion=1.0)
 {
 	n <- vcount(g)
-   dominate.greedy(g,weight=runif(n))
+   dominate.greedy(g,weight=runif(n),proportion=proportion)
 }
 
-dominate <- function(g,method="greedy")
+dominate <- function(g,method="greedy",proportion=1.0)
 {
    METHODS = c("greedy","sample","byradius")
    method <- pmatch(tolower(method),METHODS)
@@ -42,9 +42,9 @@ dominate <- function(g,method="greedy")
       stop("invalid method")
    }
 	S <- NA
-   if(method==1) S <- dominate.greedy(g)
-   else if(method==2) S <- dominate.random.sample(g)
-	else if(method==3) S <- dominate.byR(g)
+   if(method==1) S <- dominate.greedy(g,proportion=proportion)
+   else if(method==2) S <- dominate.random.sample(g,proportion=proportion)
+	else if(method==3) S <- dominate.byR(g,proportion=proportion)
    S
 }
 
